AckException class

An exception thrown when schema validation fails using parse().

It wraps a SchemaError instance, providing detailed information about the validation failure.

Implemented types
Annotations
  • @immutable

Constructors

AckException(List<SchemaError> errors)
const

Properties

errors → List<SchemaError>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
Converts this exception to a pretty-printed JSON string.
toMap() → Map<String, dynamic>
Converts this exception (specifically its underlying error) to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited