ListSchemaExtensions<ItemBoundary extends Object, ItemRuntime extends Object> extension

Adds fluent validation methods to ListSchema.

on

Methods

exactLength(int n) → ListSchema<ItemBoundary, ItemRuntime>

Available on ListSchema<ItemBoundary, ItemRuntime>, provided by the ListSchemaExtensions extension

Adds a constraint that the list must have exactly n items.
length(int n) → ListSchema<ItemBoundary, ItemRuntime>

Available on ListSchema<ItemBoundary, ItemRuntime>, provided by the ListSchemaExtensions extension

Alias for exactLength.
maxItems(int n) → ListSchema<ItemBoundary, ItemRuntime>

Available on ListSchema<ItemBoundary, ItemRuntime>, provided by the ListSchemaExtensions extension

Adds a constraint that the list must have no more than n items.
maxLength(int n) → ListSchema<ItemBoundary, ItemRuntime>

Available on ListSchema<ItemBoundary, ItemRuntime>, provided by the ListSchemaExtensions extension

Alias for maxItems.
minItems(int n) → ListSchema<ItemBoundary, ItemRuntime>

Available on ListSchema<ItemBoundary, ItemRuntime>, provided by the ListSchemaExtensions extension

Adds a constraint that the list must have at least n items.
minLength(int n) → ListSchema<ItemBoundary, ItemRuntime>

Available on ListSchema<ItemBoundary, ItemRuntime>, provided by the ListSchemaExtensions extension

Alias for minItems.
nonEmpty() → ListSchema<ItemBoundary, ItemRuntime>

Available on ListSchema<ItemBoundary, ItemRuntime>, provided by the ListSchemaExtensions extension

Adds a constraint that the list must not be empty.
notEmpty() → ListSchema<ItemBoundary, ItemRuntime>

Available on ListSchema<ItemBoundary, ItemRuntime>, provided by the ListSchemaExtensions extension

Alias for nonEmpty.
unique() → ListSchema<ItemBoundary, ItemRuntime>

Available on ListSchema<ItemBoundary, ItemRuntime>, provided by the ListSchemaExtensions extension

Adds a constraint that all items in the list must be unique.