AckType constructor

const AckType({
  1. String? name,
})

Creates an annotation to generate extension types for validated data.

The name value must be a valid Dart identifier and should omit the trailing Type suffix.

Implementation

const AckType({this.name});