name property

String? name
final

Optional custom name for the generated extension type.

If not provided, the type name is derived from the schema variable name:

  • userSchema -> UserType
  • passwordSchema -> PasswordType

If provided, the custom name is used with the Type suffix:

  • @AckType(name: 'CustomUser') -> CustomUserType
  • @AckType(name: 'MyPassword') -> MyPasswordType

Implementation

final String? name;