MaxLength class final

Adds .maxLength(length) to an inferred string schema.

Annotations
  • @Target.new({TargetKind.field, TargetKind.parameter})

Constructors

MaxLength(int length)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited