AckAllOfSchemaModel class final
- Inheritance
-
- Object
- AckSchemaModel
- AckAllOfSchemaModel
Constructors
-
AckAllOfSchemaModel({required List<
AckSchemaModel> schemas, String? title, String? description, bool nullable = false, Object? defaultValue, List<AckSchemaModelWarning> warnings = const [], Map<String, Object?> extensions = const {}}) -
const
Properties
- defaultValue → Object?
-
finalinherited
- description → String?
-
finalinherited
-
extensions
→ Map<
String, Object?> -
finalinherited
- format → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- nullable → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schemas
→ List<
AckSchemaModel> -
final
- title → String?
-
finalinherited
-
warnings
→ List<
AckSchemaModelWarning> -
finalinherited
Methods
-
finishCompositionJson(
String keyword, List< AckSchemaModel> schemas) → Map<String, Object?> -
inherited
-
finishTypeJson(
Map< String, Object?> typeJson) → Map<String, Object?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonSchema(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
withDefaultValue(
Object? defaultValue) → AckSchemaModel -
inherited
-
withDescription(
String? description) → AckSchemaModel -
inherited
-
withExtensions(
Map< String, Object?> extensions) → AckSchemaModel -
inherited
-
withJsonSchemaKeywords(
Map< String, Object?> keywords) → AckSchemaModel -
inherited
-
withNullable(
bool nullable) → AckSchemaModel -
inherited
-
withWarnings(
List< AckSchemaModelWarning> warnings) → AckSchemaModel -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited