ListSchemaExtensions<ItemBoundary extends Object, ItemRuntime extends Object> extension
Adds fluent validation methods to ListSchema.
- on
-
- ListSchema<
ItemBoundary, ItemRuntime>
- ListSchema<
Methods
-
exactLength(
int n) → ListSchema< ItemBoundary, ItemRuntime> -
Available on ListSchema<
Adds a constraint that the list must have exactlyItemBoundary, ItemRuntime> , provided by the ListSchemaExtensions extensionnitems. -
length(
int n) → ListSchema< ItemBoundary, ItemRuntime> -
Available on ListSchema<
Alias for exactLength.ItemBoundary, ItemRuntime> , provided by the ListSchemaExtensions extension -
maxItems(
int n) → ListSchema< ItemBoundary, ItemRuntime> -
Available on ListSchema<
Adds a constraint that the list must have no more thanItemBoundary, ItemRuntime> , provided by the ListSchemaExtensions extensionnitems. -
maxLength(
int n) → ListSchema< ItemBoundary, ItemRuntime> -
Available on ListSchema<
Alias for maxItems.ItemBoundary, ItemRuntime> , provided by the ListSchemaExtensions extension -
minItems(
int n) → ListSchema< ItemBoundary, ItemRuntime> -
Available on ListSchema<
Adds a constraint that the list must have at leastItemBoundary, ItemRuntime> , provided by the ListSchemaExtensions extensionnitems. -
minLength(
int n) → ListSchema< ItemBoundary, ItemRuntime> -
Available on ListSchema<
Alias for minItems.ItemBoundary, ItemRuntime> , provided by the ListSchemaExtensions extension -
nonEmpty(
) → ListSchema< ItemBoundary, ItemRuntime> -
Available on ListSchema<
Adds a constraint that the list must not be empty.ItemBoundary, ItemRuntime> , provided by the ListSchemaExtensions extension -
notEmpty(
) → ListSchema< ItemBoundary, ItemRuntime> -
Available on ListSchema<
Alias for nonEmpty.ItemBoundary, ItemRuntime> , provided by the ListSchemaExtensions extension -
unique(
) → ListSchema< ItemBoundary, ItemRuntime> -
Available on ListSchema<
Adds a constraint that all items in the list must be unique.ItemBoundary, ItemRuntime> , provided by the ListSchemaExtensions extension