SchemaValidationError class
- Inheritance
-
- Object
- SchemaError
- SchemaValidationError
- Implementers
- Annotations
-
- @immutable
Constructors
- SchemaValidationError({required String message, required SchemaContext context, Object? cause, StackTrace? stackTrace})
Properties
- cause → Object?
-
finalinherited
- context → SchemaContext
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- name → String
-
no setterinherited
- path → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → AnyAckSchema
-
no setterinherited
- stackTrace → StackTrace?
-
finalinherited
- value → Object?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toErrorString(
) → String -
Returns a human-readable error string with path information.
inherited
-
toMap(
) → Map< String, Object?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited